import { FunctionOptions, Runtime } from 'aws-cdk-lib/aws-lambda';
import { Construct } from "constructs";
import { DeployedFunction, FunctionAlarmProps, FunctionDeploymentConfig } from '../../aws-lambda';
import { BundledFunctionOptions } from "./bundled-function";
/**
 * Properties for PythonFunction.
 */
export interface PythonFunctionProps extends FunctionDeploymentConfig, BundledFunctionOptions, FunctionOptions, FunctionAlarmProps {
    /**
     * The path (relative to entry) to the index file containing the exported handler.
     *
     * @default 'index.py'
     */
    readonly index?: string;
    /**
     * The name of the exported handler in the index file.
     *
     * @default 'handler'
     */
    readonly handler?: string;
    /**
     * The runtime environment. Only runtimes of the Python family are supported.
     *
     * @default Runtime.PYTHON_3_9
     */
    readonly runtime?: Runtime;
}
/**
 * Python based Lambda Function
 */
export declare class PythonFunction extends DeployedFunction {
    static readonly DEFAULT_BUNDLE_SCRIPT = "\n  #!/usr/bin/env bash\n  set -euo pipefail\n  if [ -f requirements.txt ]; then\n    pip install --target \"${CDK_BUNDLING_OUTPUT_DIR}\" -r requirements.txt\n  fi\n  cp -a * \"${CDK_BUNDLING_OUTPUT_DIR}\"\n  ";
    static isLocalBundlingSupported(): boolean;
    /**
     * Creates a new Lambda Function
     */
    constructor(scope: Construct, id: string, props: PythonFunctionProps);
}
